==> flutter_flicker-0.64.0.tar.gz: lib/controls/form_input/number_input.dart <==
import 'package:flutter_flicker/configuration/configuration.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:google_fonts/google_fonts.dart';
import 'dart:math' as math;

class FlickerNumberInput<T> extends StatelessWidget {
  FlickerNumberInput({
    Key? key,
    required this.initialValue,
    this.onChangedInt,
    this.onChangedDouble,
    this.onChangedString,
    this.labelText,
    this.validator,
    this.padding = const EdgeInsets.only(
      top: 8.0,
      right: 8.0,
    ),
    this.width = 250,
    this.suffix,
    this.readOnly = false,
    this.prefix,
    this.numberOfDecimals = 0,
  }) : super(key: key);

  final T initialValue;
  final String? labelText;
  final ValueChanged<int>? onChangedInt;
  final ValueChanged<double>? onChangedDouble;
  final ValueChanged<String>? onChangedString;
  final FormFieldValidator<String>? validator;
  final EdgeInsetsGeometry padding;
  final double width;
  final Widget? suffix;
  final Widget? prefix;
  final bool readOnly;
  final int numberOfDecimals;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: width,
      margin: padding,
      child: TextFormField(
        readOnly: readOnly,
        initialValue: initialValue.toString(),
        onChanged: (value) {
          var valueStringToEvaluate = value;
          if (valueStringToEvaluate.endsWith('.')) {
            valueStringToEvaluate = valueStringToEvaluate.replaceAll('.', '');
          }

          if (numberOfDecimals == 0) {
            int? v = int.tryParse(valueStringToEvaluate);
            if (v == null) v = 0;
            if (this.onChangedInt != null) this.onChangedInt!(v);
          } else {
            double? v = double.tryParse(valueStringToEvaluate);
            if (v == null) v = 0;
            if (this.onChangedDouble != null) this.onChangedDouble!(v);
          }
          if (this.onChangedString != null) this.onChangedString!(value);
        },
        keyboardType:
            TextInputType.numberWithOptions(decimal: numberOfDecimals > 0),
        cursorColor: FlickerConfiguration.colors.inputCursor,
        style: GoogleFonts.barlow(
          fontSize: 15,
          color: FlickerConfiguration.colors.input,
        ),
        decoration: InputDecoration(
          suffix: suffix,
          prefix: prefix,
          enabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: FlickerConfiguration.colors.inputControlEnabledBorder,
              width: 0.2,
            ),
          ),
          focusedBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: FlickerConfiguration.colors.inputControlFocusedBorder,
            ),
          ),
          border: UnderlineInputBorder(
            borderSide: BorderSide(
              color: FlickerConfiguration.colors.inputControlBorder,
            ),
          ),
          floatingLabelBehavior: FloatingLabelBehavior.always,
          labelText: labelText != null ? labelText!.toUpperCase() : null,
          alignLabelWithHint: true,
          hintStyle: TextStyle(
            height: 2.0,
            color: FlickerConfiguration.colors.input.withAlpha(150),
          ),
          hintText: labelText != null ? labelText!.toUpperCase() : null,
          labelStyle: GoogleFonts.barlow(
            fontSize: 18,
            fontWeight: FontWeight.w600,
            color: FlickerConfiguration.colors.inputLabel,
          ),
          errorStyle: GoogleFonts.barlow(
            fontSize: 12,
          ),
          filled: false,
        ),
        inputFormatters: [
          DecimalTextInputFormatter(
            decimalRange: (numberOfDecimals == 0) ? null : numberOfDecimals,
          ),
        ],
        validator: validator,
      ),
    );
  }
}

class DecimalTextInputFormatter extends TextInputFormatter {
  DecimalTextInputFormatter({this.decimalRange})
      : assert(decimalRange == null || decimalRange > 0);

  final int? decimalRange;

  @override
  TextEditingValue formatEditUpdate(
    TextEditingValue oldValue, // unused.
    TextEditingValue newValue,
  ) {
    TextSelection newSelection = newValue.selection;
    String truncated = newValue.text;

    if (decimalRange != null) {
      String value = newValue.text;

      if (value.contains(".") &&
          value.substring(value.indexOf(".") + 1).length > decimalRange!) {
        truncated = oldValue.text;
        newSelection = oldValue.selection;
      } else if (value == ".") {
        truncated = "0.";

        newSelection = newValue.selection.copyWith(
          baseOffset: math.min(truncated.length, truncated.length + 1),
          extentOffset: math.min(truncated.length, truncated.length + 1),
        );
      }

      return TextEditingValue(
        text: truncated,
        selection: newSelection,
        composing: TextRange.empty,
      );
    }
    return newValue;
  }
}

==> flutter_flicker-0.65.0.tar.gz: lib/controls/form_input/number_input.dart <==
import 'package:flutter_flicker/configuration/configuration.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:google_fonts/google_fonts.dart';
import 'dart:math' as math;

class FlickerNumberInput<T> extends StatelessWidget {
  FlickerNumberInput({
    Key? key,
    required this.initialValue,
    this.onChangedInt,
    this.onChangedDouble,
    this.onChangedString,
    this.labelText,
    this.validator,
    this.padding = const EdgeInsets.only(
      top: 8.0,
      right: 8.0,
    ),
    this.width = 250,
    this.suffix,
    this.readOnly = false,
    this.prefix,
    this.numberOfDecimals = 0,
  }) : super(key: key);

  final T initialValue;
  final String? labelText;
  final ValueChanged<int>? onChangedInt;
  final ValueChanged<double>? onChangedDouble;
  final ValueChanged<String>? onChangedString;
  final FormFieldValidator<String>? validator;
  final EdgeInsetsGeometry padding;
  final double width;
  final Widget? suffix;
  final Widget? prefix;
  final bool readOnly;
  final int numberOfDecimals;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: width,
      margin: padding,
      child: TextFormField(
        readOnly: readOnly,
        initialValue: initialValue.toString(),
        onChanged: (value) {
          var valueStringToEvaluate = value;
          if (valueStringToEvaluate.endsWith('.')) {
            valueStringToEvaluate = valueStringToEvaluate.replaceAll('.', '');
          }

          if (numberOfDecimals == 0) {
            int? v = int.tryParse(valueStringToEvaluate);
            if (v == null) v = 0;
            if (this.onChangedInt != null) this.onChangedInt!(v);
          } else {
            double? v = double.tryParse(valueStringToEvaluate);
            if (v == null) v = 0;
            if (this.onChangedDouble != null) this.onChangedDouble!(v);
          }
          if (this.onChangedString != null) this.onChangedString!(value);
        },
        keyboardType:
            TextInputType.numberWithOptions(decimal: numberOfDecimals > 0),
        cursorColor: FlickerConfiguration.colors.inputCursor,
        style: GoogleFonts.barlow(
          fontSize: 15,
          color: FlickerConfiguration.colors.input,
        ),
        decoration: InputDecoration(
          suffix: suffix,
          prefix: prefix,
          enabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: readOnly
                  ? Colors.transparent
                  : FlickerConfiguration.colors.inputControlEnabledBorder,
              width: 0.2,
            ),
          ),
          focusedBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: FlickerConfiguration.colors.inputControlFocusedBorder,
            ),
          ),
          border: UnderlineInputBorder(
            borderSide: BorderSide(
              color: FlickerConfiguration.colors.inputControlBorder,
            ),
          ),
          floatingLabelBehavior: FloatingLabelBehavior.always,
          labelText: labelText != null ? labelText!.toUpperCase() : null,
          alignLabelWithHint: true,
          hintStyle: TextStyle(
            height: 2.0,
            color: FlickerConfiguration.colors.input.withAlpha(150),
          ),
          hintText: labelText != null ? labelText!.toUpperCase() : null,
          labelStyle: GoogleFonts.barlow(
            fontSize: 18,
            fontWeight: FontWeight.w600,
            color: FlickerConfiguration.colors.inputLabel,
          ),
          errorStyle: GoogleFonts.barlow(
            fontSize: 12,
          ),
          filled: false,
        ),
        inputFormatters: [
          DecimalTextInputFormatter(
            decimalRange: (numberOfDecimals == 0) ? null : numberOfDecimals,
          ),
        ],
        validator: validator,
      ),
    );
  }
}

class DecimalTextInputFormatter extends TextInputFormatter {
  DecimalTextInputFormatter({this.decimalRange})
      : assert(decimalRange == null || decimalRange > 0);

  final int? decimalRange;

  @override
  TextEditingValue formatEditUpdate(
    TextEditingValue oldValue, // unused.
    TextEditingValue newValue,
  ) {
    TextSelection newSelection = newValue.selection;
    String truncated = newValue.text;

    if (decimalRange != null) {
      String value = newValue.text;

      if (value.contains(".") &&
          value.substring(value.indexOf(".") + 1).length > decimalRange!) {
        truncated = oldValue.text;
        newSelection = oldValue.selection;
      } else if (value == ".") {
        truncated = "0.";

        newSelection = newValue.selection.copyWith(
          baseOffset: math.min(truncated.length, truncated.length + 1),
          extentOffset: math.min(truncated.length, truncated.length + 1),
        );
      }

      return TextEditingValue(
        text: truncated,
        selection: newSelection,
        composing: TextRange.empty,
      );
    }
    return newValue;
  }
}
